@@ -13,8 +13,8 @@ Contains everthing related to options in &xist; (apart for syntax highlighting
 which can be found in presenters.py).
 """
 
-__version__ = tuple(map(int, "$Revision: 2.11 $"[11:-2].split(".")))
-# $Source: /data/cvsroot/LivingLogic/xist/_xist/options.py,v $
+__version__ = tuple(map(int, "$Revision: 2.12 $"[11:-2].split(".")))
+# $Source: /data/cvsroot/LivingLogic/Python/xist/_xist/options.py,v $
 
 import sys, os
 
@@ -33,8 +33,8 @@ def getenvint(name, default):
 		return default
 
 
-repransi = getenvint("XSC_REPRANSI", 0)  # should ANSI escape sequences be used for dumping the DOM tree and which ones? (0=off, 1=dark background, 2=light background)
-reprtab = getenvstr("XSC_REPRTAB", "  ") # how to represent an indentation in the DOM tree?
+repransi = getenvint("LL_XIST_REPRANSI", 0)  # should ANSI escape sequences be used for dumping the DOM tree and which ones? (0=off, 1=dark background, 2=light background)
+reprtab = getenvstr("LL_XIST_REPR_TAB", "  ") # how to represent an indentation in the DOM tree?
 reprencoding = sys.getdefaultencoding()
 
 server = "localhost" # Host for server relative URLs
